@@ -22,7 +22,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 23 May 2009
+ last modified 		: 17 Dec 2009
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -41,6 +41,7 @@ aboutDialog::aboutDialog (QUrl licenseUrl, QDialog *parent) : QDialog (parent)
 	setAuthor();
 	setThanks();
 	setLicense(licenseUrl);
+	setSupport();
 }
 // SLOTS-------------------------------------------------------------------------------------
 // --------------------------------okay pressed------------------------------------------------
@@ -111,6 +112,9 @@ void aboutDialog::setThanks()
 		"<b>" + tr("Nikolas Poniros") + "</b><br>(edhunter)<br>" +
 		tr("Greek gui translator and valuable tester") + "<br><br>"
 
+		"<b>" + tr("Dimitris Kalamaras") + "</b><br>(dimitris)<br>" +
+		tr("If it wasn't him and his tutorials I would never have started this project") + "<br><br>"
+		
 		"<b>" + tr("Stephan Kleine") + "</b><br>" +
 		tr("OpenSUSE package maintainer (KDE4 Community repo) and valuable packing advisor") + "<br><br>"
 
@@ -125,10 +129,19 @@ void aboutDialog::setThanks()
 
 		"<b>" + tr("Theo Chatzimichos") + "</b><br>" +
 		tr("Gentoo ebuild maintainer") + "<br><br>"
+		
+		"<b>" + tr("Juan Luis Baptiste") + "</b><br>" +
+		tr("Mandriva package maintainer (official contrib repo)") + "<br><br>"
 
 		"<b>" + tr("Pavel Fric") + "</b><br>" +
 		tr("Czech gui translator") + "<br><br>"
 
+		"<b>" + tr("Stergios Prosiniklis") + "</b><br>" +
+		tr("Greek manual translator") + "<br><br>"
+		
+		"<b>" + tr("Carsten") + "</b><br>" +
+		tr("German gui translator") + "<br><br>"
+
 		"<b>" + tr("Wilfried Schobel") + "</b><br>" +
 		tr("German gui translator") + "<br><br>"
 
@@ -141,29 +154,45 @@ void aboutDialog::setThanks()
 		"<b>" + tr("Julien Cynober") + "</b><br>" +
 		tr("French gui translator and valuable packing advisor (and not only)") + "<br><br>"
 
-		"<b>" + tr("Denis Skorski") + "</b><br>" +
+		"<b>" + tr("Raffaele") + "</b><br>" +
+		tr("Italian gui translator") + "<br><br>"
+		
+		"<b>" + tr("Denis Skorski") + "</b><br>" + "<a href=\"http://fripohled.blogspot.com/\" TARGET=\"_blank\">fripohled.blogspot.com</a><br>" +
 		tr("Russian gui translator and valuable tester") + "<br><br>"
 
 		"<b>" + tr("Kenny Verstraete") + "</b><br>" +
 		tr("Dutch gui translator") + "<br><br>"
+
+		"<b>" + tr("Subhi Honaco") + "</b><br>" +
+		tr("Bosnian gui translator & mandriva package maintainer") + "<br><br>"
+
+		"<b>" + tr("Majed Sahli") + "</b><br>" +
+		tr("Arabic gui translator") + "<br><br>"
+
+		"<b>" + tr("Adrian Murariu") + "</b><br>" +
+		tr("Romanian gui translator") + "<br><br>"
+
+		"<b>" + tr("Andrej Znidarsic") + "</b><br>" +
+		tr("Slovenian gui translator") + "<br><br>"
+		
+		"<b>" + tr("E. Hakan Duran") + "</b><br>" +
+		tr("Turkish gui translator") + "<br><br>"
 		
 		"<b>" + tr("Javi Romero") + "</b><br>" +
 		tr("v0.3 gui designer") + "<br><br>"
 
 		"<b>" + tr("fri13") + "</b><br>" +
-		tr("v.0.3 gui designer") + "<br><br>"
-
-		"<b>" + tr("Dimitris Kalamaras") + "</b><br>(dimitris)<br>" +
-		tr("If it wasn't him and his tutorials I would never have started this project") + "<br><br>" + 
+		tr("v.0.3 gui designer") + "<br><br>" +
 
 		tr("...to all users of the ")+
 		"<br><a href=\"http://www.linuxformat.gr/\" target=\"_blank\">Hellenic Linuxformat</a>, "
 		"<a href=\"http://www.sidux.com/\" target=\"_blank\">sidux.com</a>, "
 		"<a href=\"http://www.sidux.gr/\" target=\"_blank\">sidux.gr</a>, "
-		"<a href=\"http://forum.ubuntu-gr.org/\" target=\"_blank\">ubuntu.gr</a> "
+		"<a href=\"http://forum.ubuntu-gr.org/\" target=\"_blank\">ubuntu.gr</a>, "
+		"<a href=\"http://forum.hellug.gr/\" target=\"_blank\">hellug</a>, "
 		"and <a href=\"http://www.kde-apps.org//\" target=\"_blank\">kde-apps.org</a><br>" +
 		tr("forums for their support.") + "<br><br>" +
-		tr("Especially") + "<br><b>alfisti, constantinos, promeneur, grigris, dannys,marios, Regenwald, flo, Ilias Paraponiaris, Takis Vounatsos, Lieven Tytgat, mathetes, Johan Linde, Chris Sylvester, Manos Nikiforakis, Giorgos Katsikatsos, Carsten, Ray Ambrosi, Barry Jackson and Chris (slam)</b><br>" +
+		tr("Especially") + "<br>alfisti, constantinos, promeneur, grigris, dannys,marios, Regenwald, flo, Ilias Paraponiaris, Takis Vounatsos, Lieven Tytgat, mathetes, Johan Linde, Chris Sylvester, Manos Nikiforakis, Giorgos Katsikatsos, Ray Ambrosi, Barry Jackson, Damien Cassou, Daniele Soldati Chris (slam), Paul Chapman, kingfame, Giorgos 'jeff' Finikianakis, Shelby Williams and skevo<br>" +
 		tr("that contributed to this project one way or another") + "<br><br>" +
 
 		tr("Last but no least") +":<br>"+
@@ -183,5 +212,28 @@ void aboutDialog::setLicense(QUrl licenseUrl)
 		uiA.textBrowser_License -> setSource(licenseUrl);
 
 }
+
+void aboutDialog::setSupport()
+{
+	uiA.textBrowser_Support -> setOpenLinks(TRUE);
+	uiA.textBrowser_Support -> setOpenExternalLinks(TRUE);
+
+	Text = 	"<p align=\"left\"><b>" + tr("no money") + "</b><br><br>" +
+	tr("If you like this app and would like to donate something to me personally, all you have to do is:") + "<ul><li>" +
+	tr("Give a thumbs up at:") +
+	" <a href=\"http://sourceforge.net/projects/luckybackup/\" target=\"_blank\">sourceforge.net</a></li><li>" +
+	tr("Vote good & become a fan at:") +
+	" <a href=\"http://www.kde-apps.org/content/show.php/luckyBackup?content=94391\" target=\"_blank\">kde-apps.org</a></li></ul>" +
+	tr("This is my reward :)")
+	
+	+ "<br>~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~<br><b>" + tr("money") + "</b><br><br>" + 
+	tr("I personally never had and never will accept money for this project.") + "<br>" +
+	tr("Nevertheless, I decided to use luckyBackup to support people that really need financial help.") + "<br>" +
+	tr("So, please consider it seriously to donate money that will eventually be used for a good cause.") + 
+	"<br><br><a href=\"http://luckybackup.sourceforge.net/donate.html\" target=\"_blank\"><b>" +
+	tr("donation link") + "</b></a></p>";
+
+	uiA.textBrowser_Support -> setText(Text);
+}
 // end of about.cpp ---------------------------------------------------------------------------
 
