@@ -22,7 +22,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 20 May 2009
+ last modified 		: 10 Dec 2009
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -33,6 +33,7 @@ void luckyBackupWindow::InitializeVariables()
 {
 	TotalOperations = 0;
 	currentOperation=-1;
+	NOWexecuting = FALSE;
 	modifyOK = FALSE;
 	savedProfile = TRUE;
 	taskClicked = FALSE;	
@@ -127,6 +128,8 @@ void luckyBackupWindow::retranslateUi()
 				tr("Use the 'include checkboxes' to include or not a selected task","task list tooltip - line2"));
 	ui.pushButton_up -> setToolTip(tr("Move the highlighted task up, by one position","button tooltip"));
 	ui.pushButton_down -> setToolTip(tr("Move the highlighted task down, by one position","button tooltip"));
+	ui.pushButton_nextError	-> setToolTip(tr("jump to next error","button tooltip"));
+	ui.pushButton_previousError	-> setToolTip(tr("jump to previous error","button tooltip"));
 
 	ui.groupBox_task -> setTitle(tr("Task","task groupbox (add, remove, modify buttons) label"));
 	ui.pushButton_add -> setText(tr("add","add task button label"));
@@ -144,12 +147,12 @@ void luckyBackupWindow::retranslateUi()
 	ui.checkBox_DryRun -> setText(tr("simulation","simulation checkbox label"));
 	ui.checkBox_DryRun -> setToolTip(tr("This makes rsync perform a <b>trial run</b> that doesn't make any changes (and produces mostly the same output as a real run)","simulation checkbox tooltip - line1")+".<br>"+tr("NOTE","simulation checkbox tooltip - line2")+": "+tr("Progressbar update will not be realistic","simulation checkbox tooltip - line2"));
 
-	//ui.frame_info ->
-	//ui.textBrowser_info ->
-	//ui.progressBar -> 
 	ui.label_InformationWindow -> setText(tr("Information window","information window title"));
 	ui.pushButton_exit -> setToolTip(tr("Exit","exit button tooltip. full phrase is: 'exit luckybackup'")+" "+appName);
 	ui.pushButton_exit -> setText(tr("EXIT","EXIT button label"));
+	
+	ui.pushButton_minimizeToTray -> setText(tr("minimize to tray"));
+	ui.pushButton_minimizeToTray -> setToolTip(tr("minimizes the window to the tray area"));
 }
 
 // createProfileCombo =============================================================================================================================
@@ -258,29 +261,6 @@ void luckyBackupWindow::createMenus()
 			setLanguage(action);
 		}
 	}
-
-/*
-	// toolbar sub-menu -------------------------------------------------------------------------------
-	toolbarStyleGroup = new QActionGroup(this);
-	toolbarButtonsGroup = new QActionGroup(this);
-	toolbarMenu = settingsMenu -> addMenu(tr("&Toolbar"));
-	toolbarStyleMenu = toolbarMenu -> addMenu(tr("&Style"));
-	toolbarButtonsMenu = toolbarMenu -> addMenu(tr("&Visible Buttons"));
-	//connect(toolbarGroup, SIGNAL(triggered(QAction *)), this, SLOT( createToolbar( QAction *) )  );
-	
-	QStringList ActionNames;
-	ActionNames << ui.actionSave->iconText() << ui.actionDefault->iconText() << ui.actionRename -> iconText();
-	for (count = 0; count < ActionNames.size(); ++count)
-	{
-		action = new QAction(ActionNames[count],this);
-		action -> setCheckable(TRUE);
-		action -> setChecked(TRUE);
-		//action -> setData();
-		toolbarButtonsGroup -> addAction (action);
-		toolbarButtonsMenu -> addAction(action);
-	}
-*/
-
 }
 // createToolbar =============================================================================================================================
 // create the tool bar
@@ -314,6 +294,7 @@ void luckyBackupWindow::createToolbar()
 	setToolbarAttrs();
 }
 
+
 // AlsoCreateRestore ================================================================================================================================
 //function to create another operation for RESTORE
 void luckyBackupWindow::AlsoCreateRestore()
@@ -492,6 +473,24 @@ bool luckyBackupWindow::loadCurrentProfile()
 	checkDeclared();					// Check tasks & set icons
 	loadData.append(tr("profile","info window message. full phrase: 'profile <PROFILENAME> loaded successfully'") + " <b>" + profileName + "</b> <font color=green>" + tr("loaded successfully","info window message. full phrase: 'profile <PROFILENAME> loaded successfully'") + " !!</font>");
 	ui.listWidget_operations -> setSpacing(1);
+	
+	// Check to see if this profile is scheduled and inform user  ~~~~~~~~
+	QString CronTab = "";
+	QString profileCheckCron = profileName;
+	profileCheckCron = profileCheckCron.replace(" ","\\ ");
+	QFile cronFile (cronfilename);
+	if (cronFile.open(QIODevice::ReadOnly | QIODevice::Text))		//open the cronFile
+	{
+		loadData.append("<br>"+tr("scheduled","this refers to a profile") + ": <b>");
+		QTextStream in(&cronFile);
+		while (!in.atEnd())
+			CronTab.append(in.readLine());
+		if (CronTab.contains(profileCheckCron, Qt::CaseInsensitive))
+			loadData.append(tr("YES") + "</b>");
+		else
+			loadData.append(tr("NO") + "</b>");
+	}
+	
 	return TRUE;	//profile loaded successfuly
 }
 
@@ -521,6 +520,21 @@ bool luckyBackupWindow::saveCurrentProfile()
 
 	saveData.append(tr("profile","Information window message. Full phrase: 'profile <PROFILENAME> saved successfully'") + " <b>" + profileName + "</b> <font color=green>" + tr("saved successfully","Information window message. Full phrase: 'profile <PROFILENAME> saved successfully'") + " !!</font>");
 
+	// Check to see if this profile is scheduled and inform user  ~~~~~~~~
+	QString CronTab = "";
+	QFile cronFile (cronfilename);
+	if (cronFile.open(QIODevice::ReadOnly | QIODevice::Text))		//open the cronFile
+	{
+		saveData.append("<br>"+tr("scheduled","this refers to a profile") + ": <b>");
+		QTextStream in(&cronFile);
+		while (!in.atEnd())
+			CronTab.append(in.readLine());
+		if (CronTab.contains(profileName, Qt::CaseInsensitive))
+			saveData.append(tr("YES") + "</b>");
+		else
+			saveData.append(tr("NO") + "</b>");
+	}
+	
 	savedProfile = TRUE;			//change profile status to "saved"
 	return TRUE;
 }
@@ -662,6 +676,17 @@ bool luckyBackupWindow::loadSettings()
 		settingsfile.close();
 		return FALSE;
 	}
+	
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+	//this is used for upgrade from 0.3.3 version - TAKE IT OUT at later versions !!!
+	if ( (tempAppVersion < appVersion) && (tempAppVersion < 0.34) )
+		QMessageBox::warning(this, appName,
+				tr("You have just upgraded to version 0.3.5 from an earlier version")+" <br><br>" +
+				tr("Due to code improvements regarding the scheduling function, there is no backward compatibility") +"<br><br><b>" +
+				tr("Please re-define your schedules, if any") +"...</b>",
+				QMessageBox::Ok | QMessageBox::Default);
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
 
 	in>>v;	vString = v.toString();	in >> v;	//input a label in vString and real data in v
 	while (vString != "Settings_file_end")
