@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 09 July 2009
+ last modified 		: 24 Nov 2009
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -33,10 +33,11 @@
 #define GLOBAL_H
 
 QString myHome = QDir::homePath();				// user's home directory
+QString currentUser;						// will hold the current username (definition at luckybackupwindow.cpp)
 QString const appName = "luckyBackup";				// application name
-double const appVersion = 0.33;					// application version
+double const appVersion = 0.35;					// application version
 double const validProfileVersion = 0.21;			// profile version before this a profile won't be loaded
-double const validScheduleVersion = 0.21;			// schedule version before this a schedule won't be loaded
+double const validScheduleVersion = 0.34;			// schedule version before this a schedule won't be loaded
 double const validSettingsVersion = 0.3;			// Settings file valid version
 QString luckyBackupDir = myHome + "/."+appName+"/";		// app working directory
 QString settingsFile = luckyBackupDir + "settings.ini"; 	// settings file
@@ -44,8 +45,8 @@ QString profileDir = luckyBackupDir + "profiles/";		// profiles directory
 QString defaultProfile = profileDir + "default.profile"; 	// default profile
 QString standardDefaultProfile = profileDir + "default.profile"; // standard default profile
 QString logDir = luckyBackupDir + "logs/";			// logs directory
-QString logfilename = logDir + "logfile.txt";			// logfile filename
-QString cronlogfilename = logDir + "cronLogfile.txt";		// cron logfile filename
+QString logfilename = logDir + "logfile.log";			// logfile filename - this will change according to the profile an task executed
+QString cronlogfilename = logDir + "cronLogfile.log";		// cron logfile filename
 QString scheduleDir = luckyBackupDir + "schedule/";		// schedule directory
 QString schedulefilename = scheduleDir + "schedule.dat";	// cron data filename
 QString cronfilename = scheduleDir + "luckyCron.txt";		// cron filename
@@ -65,8 +66,7 @@ QString suseManual = "/usr/share/doc/packages/luckybackup/manual/index.html";	//
 QString countStr;						//this helps displaying integers as strings
 QString message="";						//this is really handy to hold messages for dialogs
 QString messageCLI="";						//this is really handy to hold messages for the Command-Line
-int errorsFound;						//count errors when executing rync
-
+int errorsFound;						//count errors when executing rync or pre/post command
 
 // Useful variables for operations ---------------------------------------------------------------------------------------------------
 int const maxOperations = 100;		//The maximum number or operations permitted
@@ -76,16 +76,31 @@ bool modifyOK=FALSE;			//bool variable that says create or modify opeartion went
 bool modifyConnected=FALSE;		//if the operation under modification is connected to another op, this becomes TRUE
 bool DryRun=FALSE;			//shows if dry-run is checked
 bool ask=FALSE;				// becomes true if we want to ask the user if he/she wants to continue with the execution of operations or not
+bool newTaskThisIs = TRUE;		// becomes true if "add task" is pressed and FALSE if "modify" task is pressed
 bool NothingToDo=FALSE;			// Becomes true if there is nothing to do when start button pressed
 bool NothingIncluded=FALSE;		// Becomes true if there is nothing checked ("include" checkboxes)
+bool crontabUpdated=FALSE;		// Becomes true if the user's crontab is update
 QString currentProfile="";		// This holds the filename of the currently used profile
 QString profileName="";			//just holds the profile name not the full path+filename.profile
 QFile profile("");			//this is the profile QFile
+QFile logfile("");			//this is the logfile QFile
 QString CheckedData;			//String holding the current task message (OK - WARNING - CRITICAL) for info window display
 QString CheckedDataCLI;			//String holding the current task message (OK - WARNING - CRITICAL) for CLI  display
 operation *Operation[maxOperations];	//The array that holds name, source, destination & arguments of "Opereations list"
 
+bool console;		//these become true depending on the argument given at command line
+bool NoQuestions;	// do not ask any questions at console mode
+bool SkipCritical;	// skip critical tasks
+bool silentMode;	// start at silent mode
+bool runImmediately;	// execute a profile immediately after gui loads
+
 // functions ------------------------------------------------------------------------------------------------------------------------
+bool argumentsTest(int , char**);	// checks the arguments given at command-line and returns true if everything is ok
+bool loadCurrentProfile();	//loads an already created profile
+bool check_list();	//check the operations list
+bool check_dirs();	//check directories of declared profile data
+		
+void help();				// Displayes command-line usage
 void checkSyncDirs(QString, QString);	// function to check if the directories to be synced exist or are empty
 void checkBackupDirs(QString, QString);	// function to check if the source & dest dirs exist and are not empty
 int loadProfile(QString);		// loads an existing profile
@@ -93,6 +108,8 @@ bool saveProfile(QString);		// saves an existing profile
 bool checkTaskList();			// Checks if the Task list is ok to proceed
 bool checkDeclaredDirs();		// Check if the declared data are ok by calling checkBackupDirs or checkSyncDirs
 QStringList AppendArguments(operation*);// Set command's (normally rsync) arguments
+bool writeToLog;			//if the log file is ok to write this becomes TRUE
+QString logFileUpdate(QString, QString, int);		// Update the logfile with some string
 
 #endif
 
