@@ -23,7 +23,7 @@ cpp file that does all stuff needed when a signal is transmitted (eg button pres
 project version	: Please see "main.cpp" for project version
 
 developer 	: luckyb 
-last modified 	: xx May 2009
+last modified 	: 17 Dec 2009
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -36,14 +36,15 @@ last modified 	: xx May 2009
 #include "luckybackupwindow.h"
 
 //inluded sources ---------------------------------------------------------------
-#include "modifyDialog.cpp"
 #include "textDialog.cpp"
-#include "rsyncDialog.cpp"
+#include "modifyDialog.cpp"
 #include "helpBrowser.cpp"
 #include "scheduleDialog.cpp"
 #include "about.cpp"
 #include "manage.cpp"
 #include "functions.cpp"
+#include "executenow.cpp"
+#include "patternEditor.cpp"
 
 
 //class luckyBackupWindow constructor=============================================================================================
@@ -61,6 +62,17 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 		logdir.mkpath(logDir);
 	if (!scheduledir.exists())
 		scheduledir.mkpath(scheduleDir);
+	currentUser = myHome;
+	if (currentUser == "/root")
+	{
+		currentUser = tr("super user","super user is the root user");
+		this -> setWindowTitle(appName + " - " + tr("super user mode"));
+	}
+	else
+	{
+		currentUser.remove("/home/");
+		this -> setWindowTitle(appName);
+	}
 
 	// load the user settings file. If it does not exist create it
 	QFile settingsfile(settingsFile);
@@ -74,9 +86,10 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 	createMenus();		//create the top menu
 
 	retranslateUi();
-	ui.progressBar -> hide();
-//	ui.pushButton_manage -> hide();
+
+	//change gui to normal mode and resize it!!
 	this -> resize(mainWindowWidth, mainWindowHeight);
+	swapGUI("normal");
 
 	// Connections ----------------------------------------------------------------------------------------------------------
 	connect ( ui.pushButton_exit, SIGNAL( clicked() ), this, SLOT( exitApp() ) );		//pushbutton exit
@@ -104,19 +117,30 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 	connect ( ui.listWidget_operations, SIGNAL( itemClicked ( QListWidgetItem*) ), this, SLOT( checkCurrentItem() ) );
 	connect ( ui.listWidget_operations, SIGNAL( itemChanged ( QListWidgetItem* ) ), this, SLOT( taskStateChanged() ) );
 
-	// Load the default profile as soon as the app starts
-	setCurrentProfile(defaultProfile);	// set the defaultProfile as current
+	connect (ui.pushButton_minimizeToTray, SIGNAL (clicked() ), this, SLOT(minimizeTray()));//pushbutton minimize to tray
+	connect (ui.pushButton_previousError, SIGNAL (clicked() ), this, SLOT(previousErrorJump()));//pushbutton jump to prev error
+	connect (ui.pushButton_nextError, SIGNAL (clicked() ), this, SLOT(nextErrorJump()));//pushbutton jump to next error
+	
+	// Load the default profile as soon as the app starts or the one given as a command line argument
+	if (!runImmediately)
+		setCurrentProfile(defaultProfile);	// set the defaultProfile as current
 	int create = createCurrentProfile();	// if it does not exist create it
-	loadCurrentProfile();			// load the current (default) profile
+	loadCurrentProfile();			// load the current (default or not ) profile
 	createProfileCombo();	// update the profile combobox with all existing profiles and set index to currentProfile
 	InfoData.append("<p align=\"center\"><font color=magenta><b>" + tr("Welcome to","full phrase: 'Welcome to luckyBackup'") +" "
-	+ appName + " :-)</font></b></p>");
+	+ appName + ", " + currentUser + " :-)</font></b></p>");
 	if (create == 0)
 		InfoData.append(loadData);
 	else
 		InfoData.append(createData);
 	ui.textBrowser_info -> setText(InfoData);	//update the info window
 
+	if (DryRun)		// if --dry-run was given as an argument, check the relevant box
+		ui.checkBox_DryRun -> setChecked(TRUE);
+	
+	if (runImmediately)
+		start();
+	
 	//variable that helps with translations
 	QString currentLanguageIs = tr("English","Do not translate this. Enter here the language of the translation in native characters instead. This is how your translation will appear under the 'language' menu.");
 }
@@ -129,6 +153,14 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 // Exits luckybackup. Warn if the profile used is not saved
 void luckyBackupWindow::exitApp()
 {
+	if (NOWexecuting)		//if a profile execution is in progress
+	{
+		QMessageBox::warning(this, appName,
+				"<b>" + tr("profile execution in progress")+"...</b> <br><br>" +
+				tr("Please stop it before closing the main application window") + "!!",
+				QMessageBox::Ok | QMessageBox::Default);
+		return;
+	}
 	if (isProfileSaved() == 0)	//if the current profile is not saved, ask the user if he/she wants to
 		return;
 	mainWindowWidth = this -> width();
@@ -550,6 +582,7 @@ void luckyBackupWindow::add()
 {
 	modifyOK = FALSE;
 	modifyConnected = FALSE;
+	newTaskThisIs = TRUE;
 	TotalOperations = ui.listWidget_operations -> count();				//Get the Operations list size
 	currentOperation = TotalOperations;
 
@@ -587,6 +620,7 @@ void luckyBackupWindow::add()
 void luckyBackupWindow::modify()
 {
 	modifyOK = FALSE;
+	newTaskThisIs = FALSE;
 	currentOperation = ui.listWidget_operations -> currentRow();		//current operations list row number
 	if (currentOperation < 0)						//if nothing is selected do nothing
 	{
@@ -711,8 +745,8 @@ void luckyBackupWindow::manage()
 		ui.textBrowser_info -> setText(InfoData);
 		return;
 	}
-
- 	manageDialog managedialog;
+	
+	manageDialog managedialog;
 	managedialog.exec();
 }
 
@@ -788,28 +822,8 @@ void luckyBackupWindow::start()
 	}
 
 	DryRun = ui.checkBox_DryRun -> isChecked();	//set bool Dryrun according to checkbox
-	rsyncDialog rsyncdialog(this);	//rsync progress dialog
-	rsyncdialog.exec();		//show the progress dialog
-	InfoData = QDateTime::currentDateTime().toString(Qt::DefaultLocaleLongDate) + "<br>" +
-		tr("Execution of profile","full phrase: 'Execution of profile <PROFILENAME> finished'") +
-		" <b>" + profileName + "</b> " + tr("finished","full phrase: 'Execution of profile <PROFILENAME> finished'")+" !!<br>";
-	if (DryRun)
-		InfoData.append("(" + tr("simulation mode") +")");
-	else
-	{
-		//save the profile to update last execution times
-		if (!saveProfile(currentProfile))
-		{
-			InfoData.append(tr("Could not update last execution time of tasks") + "<br>" + profile.errorString());
-			savedProfile = FALSE;
-		}
-		else
-		{
-			InfoData.append(tr("Last execution time of tasks updated"));
-			savedProfile = TRUE;			//change profile status to "saved"
-		}
-	}
-	ui.textBrowser_info -> setText(InfoData);
+
+	executeNOW();
 }
 
 // schedule==========================================================================================================================================
@@ -819,6 +833,12 @@ void luckyBackupWindow::schedule()
 	//open the modify dialog and create "Operation array" item at position currentOperation
  	scheduleDialog scheduledialog; 
 	scheduledialog.exec();
+
+	if (crontabUpdated)
+		InfoData = tr("current crontab <font color=green>updated successfully") + "</font>";
+	ui.textBrowser_info -> setText(InfoData);
+	
+	crontabUpdated = FALSE;		//this is set true each time the crontab is update
 }
 
 // taskStateChanged =================================================================================================================================
