@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 22 April 2009
+ last modified 		: 26 Nov 2009
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -34,6 +34,7 @@
 
 //include  header file that qmake produces from "*.ui" created with qt designer
 #include "ui_luckybackupwindow.h"
+#include <QSystemTrayIcon>
 
 //==============================================================================================================
 //Declaration of luckyBackupWindow class (this is the main window of the app)
@@ -88,17 +89,24 @@ class luckyBackupWindow : public QMainWindow
 		void moveDown();	//SLOT: move  highlighted operation one position down
 		void schedule();	//SLOT: Open schedule dialog when Button clicked()
 
+		//execute.cpp SLOTS
+		void buttonPressed();		//SLOT when buutton pressed( see also notYet)
+		void appendRsyncOutput();	//Display o/p to textbrowser & update logfile
+		void procFinished();		//SLOT executed when syncProcess is finshed (will start a new syncProcess if any left)
+		
+		void LBtrayActivated(QSystemTrayIcon::ActivationReason reason);
+		void minimizeTray();
+		void restoreTray();
+
+		void previousErrorJump();
+		void nextErrorJump();
+
 	private:
 		Ui::luckyBackupWindow ui;
-
+		QSystemTrayIcon *LBtray;	//this is luckybackup's tray icon
 		QMenu *languageMenu;
 		QMenu *settingsMenu;
-//		QMenu *toolbarMenu;
-//		QMenu *toolbarStyleMenu;
-//		QMenu *toolbarButtonsMenu;
 		QActionGroup *languageGroup;
-//		QActionGroup *toolbarStyleGroup;
-//		QActionGroup *toolbarButtonsGroup;
 		QMenu *helpMenu;
 		QAction *action;
 		QAction *actionHelp;
@@ -109,8 +117,8 @@ class luckyBackupWindow : public QMainWindow
 		QAction *visibleProfileComboToolbar;
 		QAction *actionLockToolbars;
 		QAction *actionVisibleToolbarText;
-
-		//The following functions are inside functions.cpp
+		
+		//The following functions are inside functions.cpp~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 		void AlsoCreateRestore();		//function to create another operation for RESTORE
 		void setCurrentProfile(QString);	//function to check if a profile is valid and load it by calling loadProfile
 		bool loadCurrentProfile();		//function to  load an existing profile
@@ -139,6 +147,52 @@ class luckyBackupWindow : public QMainWindow
 		bool IsVisibleProfileToolbar;		// holds the visible state of the profile toolbar
 		bool IsVisibleToolbarText;		// holds the visible state of the toolbar text
 
+		//inside execute.cpp-----------------------------------------------------
+		void executeNOW();	//start the execution of commands (rsync & others)
+		void setNowDoing();	//Display sth in the Now Doing textBrowser
+		void executeRsync();	//execute qprocess "rsync" with Arguments
+		void swapGUI(QString);		//swaps the gui mode from normal to execute
+		int errorCount;		//used for next/previous error button
+		bool firstScroll;	//used for next/previous error button
+		bool NOWexecuting;	//becomes true if a profile execution is running
+		
+		//Progress bar variables
+		int progress_total;	//Maximum value of progress
+		int progress_done;	//Current value of progress
+
+		//variables used for rsync command
+		QString command;		//command to be executed. Normally this is "rsync"
+		QStringList rsyncArguments;	// This stringList holds all arguments for the rsync command
+		QString outputString;		//all the output of rsync is going to fit in here
+		QString outputError;		//all the error output of rsync is going to fit in here
+		QString outputInsert;		//this is used to enter application output between outputString/Error
+		QString nowDoingText;		//this is the text printed in the NowDoing textBrowser
+
+		bool sync;			//becomes true if syncing is to be executed
+		bool syncAB;			//becomes true if syncing from dirA to dirB is to be executed
+		QString dirA;			//holds the first dir to be synced
+		QString dirB;			//holds the second dir to be synced
+		
+		bool calculating;		//these 3 bools are used to diplay progress of rsync at the info window
+		bool transfering;
+		bool deleting;
+		
+		bool ExecuteBefore;		//becomes true if a before command is to be executed, not rsync !!
+		bool ExecuteAfter;		//becomes true if a after command is to be executed, not rsync !!
+		int currentBefore;		//count variable for commands to be executed before task
+		int currentAfter;		//count variable for commands to be executed before task
+		void executeBeforeTask();	//function to start execution of pre-task commands
+		void executeAfterTask();	//function to start execution of post-task commands
+
+		//tray icon stuff
+		QString trayMessage;		// tray baloon message text
+		QAction *actionAbort;
+		QAction *minimizeToTray;
+		QAction *restoreFromTray;
+		QMenu *LBtrayMenu;
+		void createTrayIcon();		// create the tray icon + relevant actions
+		bool isMinimizedToTray;		// becomes true if the gui is minimized to tray
+
 	protected:
 		void closeEvent(QCloseEvent *event);
 };
