@@ -22,7 +22,7 @@
      along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.
 
  developer 		: luckyb 
- last modified 		: 04 May 2009
+ last modified 		: 24 Nov 2009
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -38,11 +38,26 @@
 
 int main(int argc, char *argv[])
 {
+	//arguments test
+	if (!argumentsTest(argc,argv))
+		return 1;		// error code1: something wrong with the command arguments - app fail to start
+	
+	//profile validity check for console mode or gui-no profile specified (will use default)
+	if ( (runImmediately) && (!loadCurrentProfile()) )
+		return 2;		// profile is not valid or does not exist
+	
+	// task list validity check
+	if ( (runImmediately) && (!check_list()) )
+		return 3;		// task list is not ok
 
-	if (argc == 1)	//if no arguments are given execute gui
+	// declared directories check
+	if ( (runImmediately) && (!check_dirs()) )
+		return 4;		// declared dirs are not ok
+		
+	if (!console)	//execute gui
 	{
 		QApplication app(argc, argv);
-
+		
 		//translation
 		QString locale = QLocale::system().name();
 		transDir.setPath(relativeTransDir);
@@ -53,14 +68,17 @@ int main(int argc, char *argv[])
 		app.installTranslator(&appTranslator);
 
 		luckyBackupWindow luckybackup;
-		luckybackup.show();
+		if (!silentMode)
+			luckybackup.show();
 		return app.exec();
 	}
-
+	else
 	//execute luckybackup in console mode
-	commandline commandLine;
-	if (commandLine.argsTest(argc,argv))		//test for correct arguments
+	{
+		commandline commandLine;
 		return commandLine.result();		//then execute anything necessary
+	}
+
 	return 1;
 } 
 
