@@ -23,7 +23,7 @@ Display a dialog. Adds a new or modifies an existing operation
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 09 July 2009
+ last modified 		: 12 Dec 2009
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -89,10 +89,6 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
 	connect (uiM.toolButton_sourceBrowse, SIGNAL (clicked() ), signalMapper , SLOT (map()));
 	signalMapper ->	setMapping ( uiM.toolButton_destinationBrowse, 1 );
 	connect (uiM.toolButton_destinationBrowse, SIGNAL (clicked() ), signalMapper , SLOT (map()));
-	signalMapper ->	setMapping ( uiM.toolButton_excludeAddBrowse, 2 );
-	connect (uiM.toolButton_excludeAddBrowse, SIGNAL (clicked() ), signalMapper , SLOT (map()));
-	signalMapper ->	setMapping ( uiM.toolButton_includeAddBrowse, 3 );
-	connect (uiM.toolButton_includeAddBrowse, SIGNAL (clicked() ), signalMapper , SLOT (map()));
 	signalMapper ->	setMapping ( uiM.toolButton_rsyncPassword, 4 );
 	connect (uiM.toolButton_rsyncPassword, SIGNAL (clicked() ), signalMapper , SLOT (map()));
 	signalMapper ->	setMapping ( uiM.toolButton_sshPassword, 5 );
@@ -103,6 +99,15 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
 	connect (uiM.toolButton_executeAfterBrowse, SIGNAL (clicked() ), signalMapper , SLOT (map()));
 	connect(signalMapper, SIGNAL(mapped( const int)), this, SLOT( browse( const int) )  );
 
+	//Connect all pattern toolButtons with the getPattern SLOT
+	//Map all the toolButton signals and transmit a different integer depending on the toolbutton
+	QSignalMapper *signalMapper4 = new QSignalMapper(this);
+	signalMapper4 ->	setMapping ( uiM.toolButton_excludeAddPattern, 0 );
+	connect (uiM.toolButton_excludeAddPattern, SIGNAL (clicked() ), signalMapper4 , SLOT (map()));
+	signalMapper4 ->	setMapping ( uiM.toolButton_includeAddPattern, 1 );
+	connect (uiM.toolButton_includeAddPattern, SIGNAL (clicked() ), signalMapper4 , SLOT (map()));
+	connect(signalMapper4, SIGNAL(mapped( const int)), this, SLOT( getPattern( const int) )  );
+	
 	if (modifyConnected)			//if this operation is connected to another
 		uiM.checkBox_alsoCreateRestore -> setVisible(FALSE);
 	if (ArrayPosition < TotalOperations)	//if modify is pressed fill the fields first with existing operation data
@@ -175,26 +180,13 @@ void modifyDialog::browse(const int type)
 			if (newLineEdit != "")	//if something is selected indeed
 				uiM.lineEdit_destination -> setText(newLineEdit);
 			break;
-		//exclude browse button
-		case 2:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select file"),uiM.lineEdit_source -> text());
-			if (newLineEdit != "")	//if something is selected indeed
-				uiM.lineEdit_excludeAdd	-> setText(newLineEdit);
-			break;
-		//include browse button
-		case 3:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select file"),uiM.lineEdit_source -> text());
-			if (newLineEdit != "")	//if something is selected indeed
-			{
-				newLineEdit.remove(0,newLineEdit.lastIndexOf("/")+1);
-				uiM.lineEdit_includeAdd	-> setText(newLineEdit);
-			}
-			break;
 		//rsync password file browse button
-		case 4:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select rsync password file"),"/");
+		case 4:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select rsync password file"), myHome);
 			if (newLineEdit != "")	//if something is selected indeed
 				uiM.lineEdit_rsyncPassword -> setText(newLineEdit);
 			break;
 		//ssh password file browse button
-		case 5:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select ssh keyfile"),"/");
+		case 5:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select ssh keyfile"), myHome + "/.ssh");
 			if (newLineEdit != "")	//if something is selected indeed
 				uiM.lineEdit_sshPassword -> setText(newLineEdit);
 			break;
@@ -211,6 +203,36 @@ void modifyDialog::browse(const int type)
 	}
 
 }
+// pattern button pressed=====================================================================================================
+//launches the pattern editor
+void modifyDialog::getPattern(const int type)
+{	
+	if (uiM.lineEdit_source -> text() == "")	//if the source isn't defined yet
+	{
+		QMessageBox::warning(this, appName,
+			tr("Please define the source before launching the pattern editor")+" !!",
+			QMessageBox::Ok | QMessageBox::Default);
+		return;
+	}
+
+	QString NewPattern = "";
+	
+	patternEditor patterneditor(uiM.lineEdit_source -> text(), this);
+	patterneditor.exec();
+	
+	NewPattern = patterneditor.getPattern();
+	if (NewPattern == "no pattern defined yet")	// cancel pressed at the pattern editor
+		return;
+	switch (type)
+	{
+		// insert the pattern to the exclude lineEdit
+		case 0:	uiM.lineEdit_excludeAdd	-> setText(NewPattern);
+				break;
+		// insert the pattern to the incude lineEdit
+		case 1:	uiM.lineEdit_includeAdd	-> setText(NewPattern);
+				break;
+	}
+}
 // okay button pressed=======================================================================================================
 // Read all fields of modify operation dialog and fill appropriate variables
 // ...after performing some checks & changes !!
@@ -218,6 +240,7 @@ void modifyDialog::okayPressed()
 {
 	modifyOK = TRUE;
 	message = "";
+
 	//if name or source or destination is missing do not proceed -----------------------------------------------------------
 	if ( (uiM.lineEdit_name -> text() == "") || (uiM.lineEdit_destination -> text() == "") || (uiM.lineEdit_source -> text() == "")  )
 	{
@@ -292,12 +315,36 @@ void modifyDialog::okayPressed()
 				tr("Otherwise uncheck 'Remote Host' to operate locally")+"<br><br>");
 	}
 
+	bool tempCloneWarning = TRUE;
+	//use this cause the next command will set CloneWARNING to TRUE by creating a new operation
+	// only perform this if "modify is pressed, not "new" task
+	if (!newTaskThisIs)
+		tempCloneWarning = Operation[ArrayPosition] -> GetCloneWARNING ();
+	
 	Operation[ArrayPosition] = fillOperationArray();	//fill the operation array item with data from the modify dialog
+	Operation[ArrayPosition] -> SetCloneWARNING (tempCloneWarning);
 
 	if (!validation) 		//if "done" pressed and not "validation check" 
 	{
 		if (modifyOK)		//if all "data filling" went ok
-			close();	//emmit a QcloseEvent
+		{
+			//check if the user has selected "delete files on the destination" & "backup the contents of a source directory" and WARN
+			if ( (uiM.comboBox_Type -> currentIndex()==0) && (uiM.checkBox_deleteAfter -> isChecked()) &&
+				(Operation[ArrayPosition] -> GetCloneWARNING()) )
+			{
+				textDialog textdialog ("CloneWarning", "", this);
+				textdialog.exec();
+				if (textdialog.getGoOn() == 4)		//okay with "Do not show this again" checked
+				{
+					Operation[ArrayPosition] -> SetCloneWARNING (FALSE);
+					close();
+				}
+				if (textdialog.getGoOn() == 2)		//okay with "Do not show this again" NOT checked
+					close();	//emmit a QcloseEvent
+			}
+			else
+				close();	//emmit a QcloseEvent
+		}
 		else			//display a warning message
 			QMessageBox::warning(this, appName+" - "+tr("WARNING")+" !!", message, QMessageBox::Ok | QMessageBox::Default);
 	}
@@ -584,6 +631,8 @@ operation *modifyDialog::fillOperationArray()
 		pTask -> AddExecuteAfterListItem((uiM.listWidget_executeAfter -> currentItem()) -> text());
 		count++;
 	}
+	pTask -> SetByPassWARNING	( uiM.checkBox_byPassWarning -> isChecked() );
+
 	//append aguments -----------------------------------------------------------------------------------------------------------
 	pTask -> SetArgs ( AppendArguments(pTask) );
 
@@ -669,6 +718,7 @@ void modifyDialog::fillModifyWindow(operation *pTask)
 		uiM.listWidget_executeAfter -> addItem	(pTask -> GetExecuteAfterListItem(count));
 		count++;
 	}
+	uiM.checkBox_byPassWarning 	-> setChecked	(pTask -> GetByPassWARNING() );
 }
 
 // modifyTrailing ===========================================================================================================
