@@ -23,7 +23,7 @@ Display a dialog. Schedules profiles via cron
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 23 April 2009
+ last modified 		: 25 Nov 2009
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -63,7 +63,7 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 	connect(uiS.listWidget_schedule , SIGNAL( currentRowChanged(int) ), this, SLOT(fillDetails() ) );	//list item selection changed
 
 	
-	cronProcess = new QProcess(this);	//create a new qprocess (for rsync) & connect signals
+	cronProcess = new QProcess(this);	//create a new qprocess (for crontab) & connect signals
 	connect(cronProcess, SIGNAL(readyReadStandardError()), this, SLOT(appendCrontabOutput()));
 	connect(cronProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(appendCrontabOutput()));
 
@@ -75,6 +75,7 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 	uiS.pushButton_remove -> setEnabled(TRUE);
 	uiS.pushButton_cancel -> setEnabled(TRUE);
 	uiS.pushButton_schedule -> setEnabled(TRUE);
+	
 	//profile combobox initialization
 	uiS.comboBox_profile -> clear();
 	currentProfileIndex = -1;
@@ -103,10 +104,15 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 		in.setVersion(QDataStream::Qt_4_3);
 
 		QVariant v;					//we will import everything as QVariant using this temp variable
+		QString vString;				//temp variable to import "labels" of real data
 		QString tempAppName = "asxeto";
 		double tempAppVersion=0;
-		in >> v;	tempAppName = v.toString();	//input the application name & version--------------------------
-		in >> v;	tempAppVersion = v.toDouble();
+		
+		in>>v;	if (v.toString()=="appName")
+			{in >> v;	tempAppName = v.toString();}	//input the application name & version--------------------------
+		in>>v;	if (v.toString()=="appVersion")
+			{in >> v;	tempAppVersion = v.toDouble();}
+		
 		if ( (tempAppName != appName) || (tempAppVersion < validScheduleVersion) )//check if the file is a valid luckybackup schedule file
 		{
 			message = tr("The existent schedule file is not a valid luckyBackup v.")
@@ -116,36 +122,48 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 			return;
 		}
 
-		in >> v;	TotalSchedule = v.toInt();	//input the size of the schedule list first
+		in>>v;	if (v.toString()=="TotalSchedules")
+			{in >> v;	TotalSchedule = v.toInt();}	//input the size of the schedule list first
 
-		currentSchedule = 0;
+		currentSchedule = 0;	vString="";
 		while (currentSchedule < TotalSchedule)
 		{
 			schedule *tempSchedule = new schedule;
 
-			in >> v; tempSchedule	-> SetName(v.toString());
+			in>>v;	vString = v.toString();	in >> v;	//input a label in vString and real data in v
+			
+			while (vString != "current schedule end")
+			{
+				if (vString == "ScheduleName")		tempSchedule	-> SetName(v.toString());
 
-			in >> v; tempSchedule	-> SetProfilePath(v.toString());
-			in >> v; tempSchedule	-> SetProfileName(v.toString());
+				if (vString == "ProfilePath")		tempSchedule	-> SetProfilePath(v.toString());
+				if (vString == "ProfileName")		tempSchedule	-> SetProfileName(v.toString());
 
-			in >> v; tempSchedule	-> SetMonth(v.toInt());
-			in >> v; tempSchedule	-> SetMonthDay(v.toInt());
-			in >> v; tempSchedule	-> SetWeekDay(v.toInt());
-			in >> v; tempSchedule	-> SetHour(v.toInt());
-			in >> v; tempSchedule	-> SetMinute(v.toInt());
+				if (vString == "ScheduleMonth")		tempSchedule	-> SetMonth(v.toInt());
+				if (vString == "ScheduleMonthDay")	tempSchedule	-> SetMonthDay(v.toInt());
+				if (vString == "ScheduleWeekDay")	tempSchedule	-> SetWeekDay(v.toInt());
+				if (vString == "ScheduleHour")		tempSchedule	-> SetHour(v.toInt());
+				if (vString == "ScheduleMinute")	tempSchedule	-> SetMinute(v.toInt());
 
-			in >> v; tempSchedule	-> SetSkipCritical(v.toBool());
+				if (vString == "ScheduleSkipCritical")	tempSchedule	-> SetSkipCritical(v.toBool());
+				if (vString == "ScheduleConsoleMode")	tempSchedule	-> SetConsoleMode(v.toBool());
 
-			Schedule[currentSchedule] = tempSchedule;
+				in>>v;	vString = v.toString();
+				if (vString!="current schedule end")
+					in >> v;
+				else
+					Schedule[currentSchedule] = tempSchedule;
+				
+			}
 			uiS.listWidget_schedule -> addItem(scheduleText(Schedule[currentSchedule] -> GetProfileName(),
-							Schedule[currentSchedule] -> GetMonth(),
-							Schedule[currentSchedule] -> GetMonthDay(),
-							Schedule[currentSchedule] -> GetWeekDay(),
-							Schedule[currentSchedule] -> GetHour(),
-							Schedule[currentSchedule] -> GetMinute()));
+									Schedule[currentSchedule] -> GetMonth(),
+									Schedule[currentSchedule] -> GetMonthDay(),
+									Schedule[currentSchedule] -> GetWeekDay(),
+									Schedule[currentSchedule] -> GetHour(),
+									Schedule[currentSchedule] -> GetMinute()));
 			currentSchedule++;
 		}
-		TotalSchedule = uiS.listWidget_schedule -> count();	//Get the schedule list size
+		//TotalSchedule = uiS.listWidget_schedule -> count();	//Get the schedule list size
 
 		if (TotalSchedule > 0)
 		{
@@ -156,6 +174,10 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 			uiS.listWidget_schedule -> addItem(tr("No schedules are declared !!"));
 		scheduleFile.close();					//close the file
 	}
+	
+	// use this cause when the dialog starts and ther's only 1 schedule the filldetails cannot be called !!
+	currentSchedule = uiS.listWidget_schedule -> currentRow();		//current operations list row number
+	fillDetails();
 }
 //===================================================================================================================================================
 //------------------------------------------------------------------SLOTS----------------------------------------------------------------------------
@@ -199,32 +221,39 @@ void scheduleDialog::schedulePressed()
 		out.setVersion(QDataStream::Qt_4_3);
 
 		QVariant v;					//we will export everything as QVariant using this temp variable
-		v = appName;		out << v;		//output the application name 
-		v = appVersion;		out << v;		//output the application version 
-		v = TotalSchedule;	out << v;		//output the size of the schedule list 
+		v = "appName";		out << v;	v = appName;		out << v;		//output the application name 
+		v = "appVersion";	out << v;	v = appVersion;		out << v;		//output the application version 
+		v = "TotalSchedules";	out << v;	v = TotalSchedule;	out << v;		//output the size of the schedule list 
+		
 		currentSchedule = 0;
 		while (currentSchedule < TotalSchedule)
 		{
-			v = Schedule[currentSchedule] -> GetName();		out << v;
+			v = "ScheduleName";	out << v;	v = Schedule[currentSchedule] -> GetName();			out << v;
 
-			v = Schedule[currentSchedule] -> GetProfilePath();		out << v;
-			v = Schedule[currentSchedule] -> GetProfileName();		out << v;
+			v = "ProfilePath";	out << v;	v = Schedule[currentSchedule] -> GetProfilePath();		out << v;
+			v = "ProfileName";	out << v;	v = Schedule[currentSchedule] -> GetProfileName();		out << v;
 
-			v = Schedule[currentSchedule] -> GetMonth();			out << v;
-			v = Schedule[currentSchedule] -> GetMonthDay();			out << v;
-			v = Schedule[currentSchedule] -> GetWeekDay();			out << v;
-			v = Schedule[currentSchedule] -> GetHour();			out << v;
-			v = Schedule[currentSchedule] -> GetMinute();			out << v;
+			v = "ScheduleMonth";	out << v;	v = Schedule[currentSchedule] -> GetMonth();			out << v;
+			v = "ScheduleMonthDay";	out << v;	v = Schedule[currentSchedule] -> GetMonthDay();			out << v;
+			v = "ScheduleWeekDay";	out << v;	v = Schedule[currentSchedule] -> GetWeekDay();			out << v;
+			v = "ScheduleHour";	out << v;	v = Schedule[currentSchedule] -> GetHour();			out << v;
+			v = "ScheduleMinute";	out << v;	v = Schedule[currentSchedule] -> GetMinute();			out << v;
 
-			v = Schedule[currentSchedule] -> GetSkipCritical();			out << v;
+			v = "ScheduleSkipCritical";out << v;	v = Schedule[currentSchedule] -> GetSkipCritical();		out << v;
+			v = "ScheduleConsoleMode";out << v;	v = Schedule[currentSchedule] -> GetConsoleMode();		out << v;
 
+			v = "current schedule end";	out << v;
+			
 			currentSchedule++;
 		}
+		
+		v = "all schedules end";	out << v;
 		scheduleFile.close();	//close the file
 	}
 	
 	createCron();		//create a cronfile & update user's crontab
-
+	crontabUpdated = TRUE;
+	
 	close();		//emmit a QcloseEvent
 }
 
@@ -331,6 +360,7 @@ void scheduleDialog::clearScheduleDetails()
 	uiS.spinBox_hour -> setValue(0);
 	uiS.spinBox_minute -> setValue(0);
 	uiS.checkBox_skipCritical -> setCheckState(Qt::Checked);
+	uiS.checkBox_consoleMode -> setCheckState(Qt::Unchecked);
 }
 
 // fillDetails=====================================================================================================
@@ -348,10 +378,16 @@ void scheduleDialog::fillDetails()
 	uiS.comboBox_DayOfWeek -> setCurrentIndex(Schedule[currentSchedule] -> GetWeekDay());
 	uiS.spinBox_hour -> setValue(Schedule[currentSchedule] -> GetHour());
 	uiS.spinBox_minute -> setValue(Schedule[currentSchedule] -> GetMinute());
+	
 	if (Schedule[currentSchedule] -> GetSkipCritical())
 		uiS.checkBox_skipCritical -> setCheckState(Qt::Checked);
 	else
 		uiS.checkBox_skipCritical -> setCheckState(Qt::Unchecked);
+	
+	if (Schedule[currentSchedule] -> GetConsoleMode())
+		uiS.checkBox_consoleMode -> setCheckState(Qt::Checked);
+	else
+		uiS.checkBox_consoleMode -> setCheckState(Qt::Unchecked);
 }
 
 // okaySchedulePressed=====================================================================================================
@@ -401,6 +437,7 @@ void scheduleDialog::okaySchedulePressed()
 	tempOp -> SetHour (uiS.spinBox_hour -> value());
 	tempOp -> SetMinute (uiS.spinBox_minute -> value());
 	tempOp -> SetSkipCritical (uiS.checkBox_skipCritical -> isChecked());
+	tempOp -> SetConsoleMode (uiS.checkBox_consoleMode -> isChecked());
 	tempOp -> SetName (scheduleText(tempOp -> GetProfileName(),
 			tempOp -> GetMonth(),
 			tempOp -> GetMonthDay(),
@@ -515,7 +552,6 @@ QString scheduleDialog::scheduleText(QString name,int month,int monthday, int we
 //creates a cron file & updates the user's crontab
 void scheduleDialog::createCron()
 {
-	QString luckyCommand = "/usr/bin/luckybackup -c --no-questions ";
 	QString ScheduleLine = "";
 	QString ProfilePath="";
 	QString luckyEntryStart = "\n# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ luckybackup entries ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n";
@@ -529,7 +565,6 @@ void scheduleDialog::createCron()
 	int x = CronTab.indexOf(luckyEntryStart);
 	int y = CronTab.indexOf(luckyEntryEnd) + luckyEntryEnd.size() - x;
 	CronTab.remove	(x,y);					//remove luckyBackup entries from CronTab
-	//CronTab.append("\n");
 
 	QFile cronFile (cronfilename);
 	if (cronFile.exists())		//if a cronFile exists delete it
@@ -560,14 +595,18 @@ void scheduleDialog::createCron()
 			else
 				ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetWeekDay() -1 ) + "	");
 
-			ScheduleLine.append(luckyCommand);				//append command luckybackup 
-
+			if (Schedule[currentSchedule] -> GetConsoleMode())			//append -c --no-questions for CL or --silent for gui
+				ScheduleLine.append("/usr/bin/luckybackup -c --no-questions ");
+			else
+				ScheduleLine.append("env DISPLAY=:0 /usr/bin/luckybackup --silent ");
+			
 			if (Schedule[currentSchedule] -> GetSkipCritical())			//append --skip-critical
 				ScheduleLine.append("--skip-critical ");
+			
 			ProfilePath = Schedule[currentSchedule] -> GetProfilePath();
 			ProfilePath.replace(" ", "\\ ");
 			ScheduleLine.append(ProfilePath);	//append profile full path
-			ScheduleLine.append(" >> " + cronlogfilename + " 2>&1"+ "\n");		//append logfile output
+			ScheduleLine.append(" >> " + cronlogfilename + " 2>&1"+ "\n");		//append logfile output with >> instead of single >
 
 			out << ScheduleLine;
 
