@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 20 April 2009
+ last modified 		: 05 Nov 2009
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -49,7 +49,7 @@ class scheduleDialog : public QDialog
 		int currentSchedule;		//this holds the current row from the "schedule list"- starts from 0
 		void createCron();		//creates a cron file & updates the user's crontab
 		QString CronTab;		//QString to hold the user's crontab
-		int count;		//simple count variable !!
+		int count;			//simple count variable !!
 		void clearScheduleDetails();	//function: when clear (schedule details) pushbutton pressed
 		QString scheduleText(QString,int,int,int,int,int);		//returns the text displayed at the schedule list (eg execute profile default at .... every...)
 
