@@ -23,7 +23,7 @@
 // project version	: Please see "main.cpp" for project version
 
 // developer 		: luckyb 
-// last modified 	: 27 March 2009
+// last modified 	: 12 Dec 2009
 //===============================================================================================================================
 //===============================================================================================================================
 
@@ -34,7 +34,9 @@
 textDialog::textDialog (const QString type, const QString ReplaceInput, QWidget *parent) : QDialog (parent)
 {
 	uiT.setupUi(this);
-
+	uiT.checkBox_select -> setVisible(FALSE);
+	uiT.label_warning -> setVisible(FALSE);
+	
 	//connect okay & cancel pushButton SLOTs ----------------
 	connect ( uiT.pushButton_ok, SIGNAL( clicked() ), this, SLOT( okay() ) );
  	connect ( uiT.pushButton_cancel, SIGNAL( clicked() ), this, SLOT( cancel() ) );
@@ -71,6 +73,15 @@ textDialog::textDialog (const QString type, const QString ReplaceInput, QWidget
 		uiT.label_message 	-> setText(tr("Enter passphrase :"));
 		uiT.lineEdit_userInput 	-> setEchoMode (QLineEdit::Password);
 	}
+	if (type == "CloneWarning")
+	{
+		uiT.checkBox_select -> setVisible(TRUE);
+		uiT.label_warning -> setVisible(TRUE);
+		uiT.checkBox_select -> setText (tr("Do not show this again for this task"));
+		uiT.lineEdit_userInput 	-> setVisible(FALSE);
+		uiT.label_message 	-> setText(tr("You have selected to \"Backup the contents of the source directory\"<br>together with the \"delete files on the destination\" option") +"<br><br>" + tr("BEWARE, if your intention is NOT to clone source to destination !!") +"<br><br>" + 
+				tr("Are you sure you wish to proceed ??") + "<br><br>");
+	}
 }
 // SLOTS-------------------------------------------------------------------------------------
 // --------------------------------okay pressed------------------------------------------------
@@ -101,11 +112,15 @@ void textDialog::okay()
 
 	if (userInput == profileName)
 		GoOn = 3;
+	
+	if (uiT.checkBox_select -> isChecked())		//"Do not show this again check box
+		GoOn = 4;
 	close();
 }
 // --------------------------------cancel pressed------------------------------------------------
 void textDialog::cancel()
 {
+	//GoOn == 0
 	close();
 }
 
